<?php
class digitalworld_latest_posts_widget extends WP_Widget
{
    function __construct()
    {
        /* Widget settings. */
        $widget_ops = array( 'classname' => 'digitalworld_latest_posts_widget block-recent-post', 'description' => esc_html__('A widget that displays your latest posts from all categories or a certain', 'digitalworld') );
        /* Create the widget. */
        parent::__construct( 'digitalworld_latest_posts_widget', esc_html__('Digitalworld: Latest Posts', 'digitalworld'), $widget_ops );
    }
    function widget( $args, $instance )
    {
        extract( $args );
        $title        = apply_filters('widget_title', $instance['title'] );
        $categories   = $instance['categories'];
        $number       = $instance['number'];
        $query        = array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'ignore_sticky_posts' => 1, 'cat' => $categories);
        $loop         = new WP_Query($query);
        if ( $loop->have_posts() ) :
            echo balanceTags($before_widget);
            if ( $title ) {
                echo balanceTags($before_title . $title . $after_title);
            } ?>
            <div class="block-content">
            <ul class="latest-post">
            <?php  while ( $loop->have_posts() ) : $loop->the_post(); ?>
            <li <?php post_class('clearfix');?>>
                <?php if ( has_post_thumbnail() ) : ?>
                    <div class="item-photo">
                        <a href="<?php the_permalink(); ?>" rel="bookmark">
                            <?php
                            $image_featured = digitalworld_resize_image( get_post_meta( get_the_ID() , '_thumbnail_id', true ) , null, 85, 88, true, false );
                            $image_featured = $image_featured['url'];
                            ?>
                            <img src="<?php echo esc_url($image_featured); ?>" alt="<?php the_title(); ?>" />
                        </a>
                    </div>
                <?php endif; ?>
                <div class="item-detail">
                    <a class="item-name" href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
                    <div class="item-athur">
                        <?php echo get_the_date('F j, Y');?>
                    </div>
                </div>
            </li>
        <?php endwhile; ?>
            </ul>
            </div>
            <?php
            wp_reset_postdata();
            echo balanceTags($after_widget);
        endif;
    }
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['categories'] = $new_instance['categories'];
        $instance['number'] = strip_tags( $new_instance['number'] );
        return $instance;
    }
    function form( $instance )
    {
        $defaults = array( 'title' => esc_html__('Latest Posts', 'digitalworld'), 'number' => 5, 'categories' => '');
        $instance = wp_parse_args( (array) $instance, $defaults ); ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', 'digitalworld'); ?></label>
            <input  type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo balanceTags($instance['title']); ?>"  />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('categories')); ?>">Filter by Category:</label>
            <select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="widefat categories" style="width:100%;">
                <option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>><?php esc_html_e('All categories','digitalworld');?></option>
                <?php $categories = get_categories('hide_empty=0&depth=1&type=post'); ?>
                <?php foreach($categories as $category) { ?>
                    <option value='<?php echo esc_html($category->term_id); ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_html($category->cat_name); ?></option>
                <?php } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e('Number of posts to show:', 'digitalworld'); ?></label>
            <input  type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" value="<?php echo esc_html($instance['number']); ?>" size="3" />
        </p>
        <?php
    }
}
add_action( 'widgets_init', 'digitalworld_latest_posts_widget' );
function digitalworld_latest_posts_widget() {
    register_widget( 'digitalworld_latest_posts_widget' );
}