<?php
/**
 * The template for displaying product widget entries
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-widget-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see    https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.5
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) {
	exit;
}

global $product;

$digitalworld_enable_lazy = digitalworld_option( 'digitalworld_enable_lazy', '1' );

?>

<li class="item-product">

	<?php do_action( 'woocommerce_widget_product_item_start', $args ); ?>

    <div class="thumb">
        <a href="<?php echo esc_url( $product->get_permalink() ); ?>"
           title="<?php echo esc_attr( $product->get_name() ); ?>">
			<?php
			$image_thumb = digitalworld_resize_image( $product->get_image_id(), null, 90, 90, true, true, false );
			?>
			<?php if ( $digitalworld_enable_lazy == '1' ): ?>
                <img width="<?php echo esc_attr( $image_thumb['width'] ); ?>"
                     height="<?php echo esc_attr( $image_thumb['height'] ); ?>"
                     class="attachment-post-thumbnail wp-post-image lazy owl-lazy"
                     src="<?php echo trailingslashit( get_template_directory_uri() ) . 'images/1x1.jpg' ?>"
                     data-src="<?php echo esc_attr( $image_thumb['url'] ) ?>"
                     data-original="<?php echo esc_attr( $image_thumb['url'] ) ?>" alt=""/>
			<?php else: ?>
                <img width="<?php echo esc_attr( $image_thumb['width'] ); ?>"
                     height="<?php echo esc_attr( $image_thumb['height'] ); ?>"
                     class="attachment-post-thumbnail wp-post-image" src="<?php echo esc_attr( $image_thumb['url'] ) ?>"
                     alt=""/>
			<?php endif; ?>
        </a>
    </div>
    <div class="info">
        <span class="product-title">
            <a href="<?php echo esc_url( $product->get_permalink() ); ?>"><?php echo wp_kses_post( $product->get_name() ); ?></a>
        </span>
		<?php if ( !empty( $show_rating ) ) : ?>
			<?php echo wc_get_rating_html( $product->get_average_rating() ); // PHPCS:Ignore  ?>
		<?php endif; ?>
        <span class="price">
			<?php echo $product->get_price_html(); ?>
		</span>
    </div>

	<?php do_action( 'woocommerce_widget_product_item_end', $args ); ?>
</li>
